# Import modules, functions & classes
from tfv.timeseries import FvTimeSeries
from tfv.visual import *


# ----------------------------------------------------- Input ----------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = r'HYD_002_time_series.nc'

# Variable and location to plot
variable = 'H'
location = 'Point_4'

# Axes settings
y_label = 'Water Surface Elevation [mAHD]'
x_label = 'Date [dd/mm/yyyy]'
date_fmt = '%d/%m/%Y'

x_limit = [dt.datetime(2011, 5, 1), dt.datetime(2011, 5, 7)]
y_limit = [-0.2, 0.3]

# Line style settings
line_spec = dict(linestyle='-', color='orange', linewidth=1)

# Output settings
save_fig = True
output_folder = 'plots'
output_name = 'TS_2D_Water_Level_Point.png'

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare the figure
f = plt.figure(figsize=(200*0.04, 120*0.04))
ax = f.add_axes([0.150, 0.225, 0.750, 0.750])
ax.grid(linestyle='dotted')

# Set axes labels
ax.set_xlabel(x_label)
ax.set_ylabel(y_label)

# Set axes limits
ax.set_xlim(x_limit)
ax.set_ylim(y_limit)

# Format axes
fmt = DateFormatter(date_fmt)
ax.xaxis.set_major_formatter(fmt)
f.autofmt_xdate()

# Prepare extraction object
res_file = res_folder + '\\' + res_name
time_series = FvTimeSeries(res_file)

# Extract the data (x, y)
x = datetime(time_series.time_vector)
y = time_series.get_data(variable, location)

# Add polyline object to axes
ax.add_line(Line2D(x, y, **line_spec))

# Show the figure
plt.show(block=True)

# Print figure
if save_fig:
    f.savefig(output_folder + '\\' + output_name, dpi=300)
