# Import modules, functions & classes
from tfv.timeseries import FvTimeSeries
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and names
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'

res_files = \
    {   # label:    model file
        'Model 1': 'HYD_000_time_series.nc',
        'Model 2': 'HYD_001_time_series.nc',
        'Model 3': 'HYD_002_time_series.nc'
    }

# Variable and location to plot
variable = 'hyp(V_x, V_y)'
location = 'Point_3'

# Depth averaging settings
datum = 'sigma'
limits = [0, 1]

# Axes settings
y_label = 'Velocity Magnitude [m/s]'
x_label = 'Date [dd/mm/yyyy]'
date_fmt = '%d/%m/%Y'

x_limit = [dt.datetime(2011, 5, 1), dt.datetime(2011, 5, 7)]
y_limit = [0, 0.15]

# Line style settings
line_spec = dict(linestyle='-', linewidth=1)
colours = cm.viridis(np.linspace(0, 1, len(res_files)))

# Output settings
save_fig = True
output_folder = 'plots'
output_name = 'TS_3D_model_comparison.png'

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare the figure
f = plt.figure(figsize=(200*0.04, 120*0.04))
ax = f.add_axes([0.150, 0.225, 0.750, 0.750])
ax.grid(linestyle='dotted')

# Set axes labels
ax.set_xlabel(x_label)
ax.set_ylabel(y_label)

# Set axes limits
ax.set_xlim(x_limit)
ax.set_ylim(y_limit)

# Format axes
fmt = DateFormatter(date_fmt)
ax.xaxis.set_major_formatter(fmt)
f.autofmt_xdate()

# Extract the data (x, y) & add polyline
ii = 0
for label, file in res_files.items():
    res_file = res_folder + '\\' + file
    time_series = FvTimeSeries(res_file)
    expression = Expression(variable)

    x = datetime(time_series.time_vector)
    y = time_series.get_data(expression, location, datum, limits)

    ax.add_line(Line2D(x, y, label=label, color=colours[ii], **line_spec))
    ii += 1

plt.legend()

# Show the figure
plt.show(block=True)

# Print figure
if save_fig:
    f.savefig(output_folder + '\\' + output_name, dpi=300)
