# Import modules, functions & classes
from tfv.visual import *
from tfv.mldatetime import *

# ----------------------------------------------------- Input ----------------------------------------------------------
# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = r'HYD_002_FLUX.csv'

# Flux variable & node string ID to plot
variable = 'FLOW'
node_string = 1
time_fmt = '%d/%m/%Y %H:%M:%S'

# Axes settings
y_label = 'Flow Rate [m^3/s]'
x_label = 'Date [dd/mm/yyyy]'
date_fmt = '%d/%m/%Y'

x_limit = [dt.datetime(2011, 5, 1), dt.datetime(2011, 5, 7)]
y_limit = [0, 30]

# Line style settings
line_spec = dict(linestyle='-', color='orange', linewidth=1)

# Output settings
save_fig = False
output_folder = 'plots'
output_name = 'TS_2D_NS1_Flow.png'

# ----------------------------------------------------- Script ---------------------------------------------------------

# Read in data
res_file = res_folder + '\\' + res_name
field = 'NS{}_{}'.format(node_string, variable)
with open(res_file) as file:
    # Get lines in file
    lines = file.readlines()
    header = lines.pop(0).split(',')

    # Find data index
    index = None
    for ii, entry in enumerate(header):
        if entry.split(' ')[0] == field:
            index = ii

    # Check if data was found
    if index is None:
        raise ValueError('Flux header {} not found'.format(field))

    # Store data in numpy array
    n = len(lines)
    x = np.empty((n,), dtype='<U100')
    y = np.empty((n,), dtype=np.float64)
    for ii in range(n):
        entries = lines[ii].split(',')
        x[ii] = entries[0]
        y[ii] = float(entries[index])

# Convert time string into datetime
x = datetime(x, time_fmt)

# Prepare the figure
f = plt.figure(figsize=(200*0.04, 120*0.04))
ax = f.add_axes([0.150, 0.225, 0.750, 0.750])
ax.grid(linestyle='dotted')

# Set axes labels
ax.set_xlabel(x_label)
ax.set_ylabel(y_label)

# Set axes limits
ax.set_xlim(x_limit)
ax.set_ylim(y_limit)

# Format axes
fmt = DateFormatter(date_fmt)
ax.xaxis.set_major_formatter(fmt)
f.autofmt_xdate()

# Add polyline object to axes
ax.add_line(Line2D(x, y, **line_spec))

# Show the figure
plt.show(block=True)

# Print figure
if save_fig:
    f.savefig(output_folder + '\\' + output_name, dpi=300)



