# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Variable to plot
variable = 'hyp(V_x, V_y)'

# Point location of profile to plot
point = [159.0906,  -31.3814]

# Axes settings
x_limit = [0, 1]
y_limit = [-6, 0]

y_label = 'Elevation [mMSL]'
x_label = 'Current Magnitude [m/s]'

# Line style settings
line_spec = dict(linestyle='-', color='orange', linewidth=1)

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Prepare viewer object, figure & axes
viewer = Viewer(size=(160, 160), units='mm')
ax = viewer.figure.add_axes([0.1, 0.2, 0.85, 0.75])

# Plot profile visual
profile = ProfileCell(ax, xtr, variable, point, **line_spec)

# Set axes limits
ax.set_xlim(x_limit)
ax.set_ylim(y_limit)

# Set axes labels
ax.set_xlabel(x_label)
ax.set_ylabel(y_label)

# Show the figure
plt.show(block=True)