# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Variable to plot
variable = 'hyp(V_x, V_y)'
variable_name = 'Velocity Magnitude [m/s]'

# Depth averaging settings
datum = 'sigma'
limits = [0, 1]

# Colour settings
col_spec = dict(cmap=cm.jet, clim=[0, 0.5], norm=Normalize(0, 0.5))

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(200, 200), units='mm', format='hms')
ax = viewer.figure.subplots(1, 1)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Plot the sheet patch collection
sheet = SheetPatch(ax, xtr, variable, datum, limits, shading='flat', edgecolor='face', **col_spec)

# Finish formatting plot
ax.set_aspect('equal')
for tick in ax.get_xticklabels():
        tick.set_rotation(20)

# Add colour bar
col_bar = ColourBar(sheet.patch, offset=0.08)
col_bar.ax.set_xlabel(variable_name)

# Show plot
plt.show(block=True)