# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Sheet variable to plot
sheet_variable = 'hyp(V_x, V_y)'
variable_name = 'Velocity Magnitude [m/s]'

# Vector variables to plot
vector_variables = ['V_x', 'V_y']

# Depth averaging settings
datum = 'sigma'
limits = [0, 1]

# Colour settings
col_spec = dict(cmap=cm.jet, clim=[0.0, 0.5], norm=Normalize(0.0, 0.5))

# Vector settings
vec_spec = dict(angles='uv', scale_units='dots', scale=1/200, width=0.002,
                headwidth=2.5, headlength=4, pivot='middle', minlength=2)

# Output settings
output_ts = datetime((2011, 5, 2, 0, 0, 0))
output_te = datetime((2011, 5, 7, 0, 0, 0))
output_folder = 'plots'
output_name = 'Hydrodynamic_Sheet_Animation.mp4'

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(200, 200), units='mm')
ax = viewer.figure.subplots(1, 1)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Plot the sheet patch collection
sheet = SheetPatch(ax, xtr, sheet_variable, datum, limits, shading='flat', edgecolor='face', **col_spec)
vector = SheetVector(ax, xtr, vector_variables, datum, limits, zorder=1, **vec_spec)

# Finish formatting plot
ax.set_aspect('equal')
for tick in ax.get_xticklabels():
        tick.set_rotation(20)

# Add colour bar
col_bar = ColourBar(sheet.patch, offset=0.08)
col_bar.ax.set_xlabel(variable_name)

# Write the animation
out_file = output_folder + '\\' + output_name
viewer.animate(out_file, output_ts.timestamp(), output_te.timestamp(), 3600, fps=10, dpi=300)

# Show plot
plt.show(block=True)
