# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# First sheet variable to plot
sheet_variable_1 = 'H'
variable_name_1 = 'Water Surface Elevation [m]'

# Second sheet variable to plot
sheet_variable_2 = 'hyp(V_x, V_y)'
variable_name_2 = 'Velocity Magnitude [m/s]'

# Vector variable to plot
vector_variable = ['V_x', 'V_y']

# Depth averaging settings
datum = 'sigma'
limits = [0, 1]

# Color settings
col_spec_1 = dict(cmap=cm.jet, clim=(-0.2, 0.2), norm=Normalize(-0.2, 0.2))
col_spec_2 = dict(cmap=cm.jet, clim=(0, 0.5), norm=Normalize(0, 0.5))

# Vector settings
vec_spec = dict(angles='uv', scale_units='dots', scale=1/200, width=0.002,
                headwidth=2.5, headlength=4, pivot='middle', minlength=2)

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(225, 225), units='mm')
ax = viewer.figure.subplots(1, 2)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Plot the sheet patch collection
sheet_1 = SheetPatch(ax[0], xtr, sheet_variable_1, datum, limits, shading='flat', edgecolor='face', **col_spec_1)
sheet_2 = SheetPatch(ax[1], xtr, sheet_variable_2, datum, limits, shading='flat', edgecolor='face', **col_spec_2)

vector_1 = SheetVector(ax[0], xtr, vector_variable, datum, limits, zorder=1, **vec_spec)
vector_2 = SheetVector(ax[1], xtr, vector_variable, datum, limits, zorder=1, **vec_spec)

# Finish formatting plot
for axes in ax:
    axes.set_aspect('equal')
    for tick in axes.get_xticklabels():
            tick.set_rotation(20)

# Add colour bars
col_bar_1 = ColourBar(sheet_1.patch, offset=0.08)
col_bar_1.ax.set_xlabel(variable_name_1)

col_bar_2 = ColourBar(sheet_2.patch, offset=0.08)
col_bar_2.ax.set_xlabel(variable_name_2)

# Show plot
plt.show(block=True)
