# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
base_res_name = 'WQ_000_WQ.nc'
dev_res_name = 'WQ_001_WQ.nc'

# First sheet variable to plot
sheet_variable = 'WQ_OXY_OXY'
base_variable_name = 'Base Case Dissolved Oxygen [mg/L]'
dev_variable_name = 'Developed Case Dissolved Oxygen [mg/L]'

# Vector variable to plot
vector_variable = ['V_x', 'V_y']

# Depth averaging settings
datum = 'sigma'
limits = [0, 1]

# Color settings
col_spec_var = dict(cmap=cm.jet, clim=(200, 300), norm=Normalize(200, 300))
col_spec_dif = dict(cmap=cm.RdBu_r, clim=(-3, 3), norm=Normalize(-3, 3))

# Vector settings
vec_spec = dict(angles='uv', scale_units='dots', scale=1/100, width=0.002,
                headwidth=2.5, headlength=4, pivot='middle', minlength=2)

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(300, 150), units='mm')
ax = viewer.figure.subplots(1, 3)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Prepare extractor object
base_res_file = res_folder + '\\' + base_res_name
dev_res_file = res_folder + '\\' + dev_res_name

base_xtr = FvExtractor(base_res_file)
dev_xtr = FvExtractor(dev_res_file)

# Plot the sheet patch collection
base_sheet = SheetPatch(ax[0], base_xtr, sheet_variable, datum, limits, shading='flat', edgecolor='face', **col_spec_var)
dev_sheet = SheetPatch(ax[1], dev_xtr, sheet_variable, datum, limits, shading='flat', edgecolor='face', **col_spec_var)
diff_sheet = DeltaSheetPatch(ax[2], (dev_xtr, base_xtr), sheet_variable, datum, limits, shading='flat', edgecolor='face', **col_spec_dif)

# Finish formatting plot
for axes in ax:
    # axes.set_aspect('equal')
    for tick in axes.get_xticklabels():
            tick.set_rotation(20)

# Add colour bars
base_col_bar = ColourBar(base_sheet.patch, offset=0.08)
base_col_bar.ax.set_xlabel(base_variable_name)

dev_col_bar = ColourBar(dev_sheet.patch, offset=0.08)
dev_col_bar.ax.set_xlabel(dev_variable_name)

diff_col_bar = ColourBar(diff_sheet.patch, offset=0.08)
diff_col_bar.ax.set_xlabel('Difference [m]')

# Show plot
plt.show(block=True)
