# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Variable to plot
variable = 'RHOW'
variable_name = 'Density [kg/m^3]'

# Depth averaging settings
datum = 'sigma'
limits = [0, 1]

# Colour settings
col_spec = dict(cmap=cm.jet, clim=(1000, 1025), norm=Normalize(1000, 1025))

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(200, 200), units='mm')
ax = viewer.figure.subplots(1, 1)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Get maximum density data
data_max = np.zeros((xtr.nc2,))
time = xtr.time_vector
for ii in range(len(time)):
        data_ii = xtr.get_sheet_cell(variable, ii, datum, limits)
        data_max = np.maximum(data_max, data_ii)


# Plot the sheet patch collection
sheet = SheetPatch(ax, xtr, variable, datum, limits, shading='flat', edgecolor='face', **col_spec)

# Set the data to the calculated maximum values
sheet.patch.set_array(data_max)

# Set title
viewer.text = 'Maximum Value'
viewer.figure.canvas.draw()

# Finish formatting plot
ax.set_aspect('equal')
for tick in ax.get_xticklabels():
        tick.set_rotation(20)

# Add colour bar
col_bar = ColourBar(sheet.patch, offset=0.08)
col_bar.ax.set_xlabel(variable_name)

# Show plot
plt.show(block=True)