# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Variable to plot
variable = 'SAL'
variable_name = 'Salinity [PSU]'

# Polyline file folder and name
line_folder = '.'
line_name = 'polyline.csv'

# Colour settings
col_spec = dict(cmap=cm.jet, clim=[0, 35], norm=Normalize(0, 35))

# Axes settings
x_label = 'Chainage [m]'
y_label = 'Elevation [m]'
y_lim = (-10, 2)

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(200, 200), units='mm')
ax = viewer.figure.subplots(1, 1)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Get Polyline
polyline = list()
line_file = line_folder + '\\' + line_name
with open(line_file, 'r') as file:
    lines = file.readlines()
    for line in lines[1:]:
        polyline.append([float(aa) for aa in line.split(',')])

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Plot the curtain patch collection
curtain = CurtainPatch(ax, xtr, variable, polyline, edgecolor='face', **col_spec)

# Finish formatting plot
ax.set_ylim(y_lim[0], y_lim[1])
for tick in ax.get_xticklabels():
    tick.set_rotation(0)
ax.set_xlabel(x_label)
ax.set_ylabel(x_label)

# Add colour bar
col_bar = ColourBar(curtain.patch, offset=0.10)
col_bar.ax.set_xlabel(variable_name)

# Show plot
plt.show(block=True)