# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Variable specification to plot
variable_spec = \
    {   # variable name: plotting specification
        'Current Magnitude [m/s]': dict(expression='hyp(V_x, V_y)', clim=(0, 0.5), norm=Normalize(0, 0.5), edgecolor='face'),
        'Salinity [PSU]':          dict(expression='SAL', clim=(0, 35), norm=Normalize(0, 35), edgecolor='face'),
        'Temperature [Deg. Cel.]': dict(expression='TEMP', clim=(10, 25), norm=Normalize(10, 25), edgecolor='face'),
        'Density [kg/m^3]':        dict(expression='RHOW', clim=(1000, 1025), norm=Normalize(1000, 1025), edgecolor='face')
    }

# Polyline file folder and name
line_folder = '.'
line_name = 'polyline.csv'

# Axes settings
x_label = 'Chainage [m]'
y_label = 'Elevation [m]'
y_lim = (-10, 2)

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(180, 220), units='mm')
n = len(variable_spec.keys())
ax = viewer.figure.subplots(n, 1)
viewer.figure.subplots_adjust(bottom=0.125, top=0.95, hspace=0.175)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Get Polyline
polyline = list()
line_file = line_folder + '\\' + line_name
with open(line_file, 'r') as file:
    lines = file.readlines()
    for line in lines[1:]:
        polyline.append([float(aa) for aa in line.split(',')])

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Plot the curtain patch collection for each variable specification
for ii, key in enumerate(variable_spec.keys()):
    # Get specification
    spec = variable_spec[key]
    expression = spec.pop('expression')

    # Make curtain
    curtain = CurtainPatch(ax[ii], xtr, expression, polyline, **spec)

    # Add colour bar
    ColourBar(curtain.patch, location='right', offset=0.05, thickness=0.01, label=key)

    # Finish formatting axes
    ax[ii].set_ylim(y_lim[0], y_lim[1])
    for tick in ax[ii].get_xticklabels():
        tick.set_rotation(0)
    ax[ii].set_xlabel(x_label)
    ax[ii].set_ylabel(x_label)

# Show plot
plt.show(block=True)