# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.timeseries import FvTimeSeries
from tfv.visual import *

# --------------------------------------------------- User Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Time series file folder and name
# ts_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
ts_folder = r'C:\Users\jonah.chorley\Documents\DEV\python\tfv\working\tutorial\results'
ts_name = 'HYD_002_time_series.nc'

# Polyline file folder and name
line_folder = '.'
line_name = 'polyline.csv'

# Time series settings
time_series_variable_name = 'Velocity Magnitude [m/s]'

time_series_args = dict(expression='hyp(V_x, V_y)', location='Point_4', datum='sigma', limits=(0, 1))
time_series_fmt = dict(linestyle='-', color='orange', linewidth=1)

time_series_x_limit = [dt.datetime(2011, 5, 1), dt.datetime(2011, 5, 7)]
time_series_y_limit = [0, 0.5]

# Curtain settings
curtain_variable_name = 'Velocity Magnitude [m/s]'

curtain_args = dict(expression='hyp(V_x, V_y)')
curtain_fmt = dict(cmap=cm.jet, clim=[0, 0.5], norm=Normalize(0, 0.5))

curtain_x_limit = [0.00, 12000]
curtain_y_limit = [-10.0, 2.00]

# Profile settings
profile_variable_name = 'Velocity Magnitude [m/s]'

profile_args = dict(expression='hyp(V_x, V_y)', point=[159.0906,  -31.3814])
profile_fmt = dict(linestyle='-', color='orange', linewidth=1)

profile_x_limit = [0.0, 0.5]
profile_y_limit = [-6.0, 0.0]

# Sheet settings
sheet_variable_name = 'Velocity Magnitude [m/s]'

sheet_args = dict(expression='hyp(V_x, V_y)', datum='sigma', limits=[0, 1])
sheet_fmt = dict(cmap=cm.jet, clim=[0, 0.5], norm=Normalize(0, 0.5), zorder=0, edgecolor='face')

vector_args = dict(expression=['V_x', 'V_y'], datum='sigma', limits=[0, 1])
vector_fmt = dict(angles='uv', scale_units='dots', scale=1/50, width=0.002,
                  headwidth=2.5, headlength=4, pivot='middle', minlength=2)

sheet_x_limit = [159.0267, 159.1815]
sheet_y_limit = [-31.4422, -31.3505]

# ----------------------------------------------------- Script ---------------------------------------------------------

# Read in curtain polyline
polyline = list()
line_file = line_folder + '\\' + line_name
with open(line_file, 'r') as file:
    lines = file.readlines()
    for line in lines[1:]:
        polyline.append([float(aa) for aa in line.split(',')])

# Prepare viewer object, figure & axes
viewer = Viewer(size=(260, 220), units='mm')
ax = viewer.figure.subplots(2, 2)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95, wspace=0.20)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Prepare time series object
ts_file = ts_folder + '\\' + ts_name
ts = FvTimeSeries(ts_file)

# Initialize Visual object
sheet = SheetPatch(ax[0, 1], xtr, **sheet_args, **sheet_fmt)
vectors = SheetVector(ax[0, 1], xtr, **vector_args, **vector_fmt)
curtain = CurtainPatch(ax[1, 1], xtr, **curtain_args, polyline=polyline, **curtain_fmt)
profile = ProfileCell(ax[1, 0], xtr, **profile_args, **profile_fmt)
glider = SeriesGlider(ax[0, 0], ts, **time_series_args, **time_series_fmt)

# Add colour bars
col_bar = ColourBar(sheet.patch, offset=0.075, thickness=0.015)
col_bar.ax.set_xlabel(sheet_variable_name)

col_bar = ColourBar(curtain.patch, offset=0.075, thickness=0.015)
col_bar.ax.set_xlabel(curtain_variable_name)

# Finish formatting axes
# Time series
ax[0,0].set_ylim(time_series_y_limit)
ax[0,0].set_xlim(time_series_x_limit)
ax[0,0].grid(linestyle = 'dotted')
ax[0,0].set_ylabel(time_series_variable_name)

fmt = DateFormatter('%d/%m/%Y')
ax[0, 0].xaxis.set_major_formatter(fmt)
for tick in ax[0, 0].get_xticklabels():
        tick.set_rotation(20)

# Sheet
ax[0,1].set_xlim(sheet_x_limit)
ax[0,1].set_ylim(sheet_y_limit)

for tick in ax[0, 1].get_xticklabels():
        tick.set_rotation(20)

# Profile
ax[1,0].set_xlim(profile_x_limit)
ax[1,0].set_ylim(profile_y_limit)
ax[1,0].grid(linestyle = 'dotted')
ax[1,0].set_xlabel(profile_variable_name)
ax[1,0].set_ylabel('Elevation [mMSL]')

# Curtain
ax[1,1].set_xlim(curtain_x_limit)
ax[1,1].set_ylim(curtain_y_limit)

# Show the plot
plt.show(block=True)