# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS HERE\results'
res_name = 'HYD_002.nc'

# Polyline file folder and name
line_folder = '.'
line_name = 'polyline.csv'

# Variable to plot
variable = 'RHOW'
variable_name = 'Density [kg/m^3]'

# Color settings
col_spec = dict(cmap=cm.jet, clim=(1000, 1025), norm=Normalize(1000, 1025))

# Sheet depth averaging settings
sheet_datum = 'sigma'
sheet_limits = [0, 1]

# Curtain plot axes setting
curtain_x_limit = [0.00, 12000]
curtain_y_limit = [-10.0, 2.00]

# Line style for polyline on sheet
line_spec = dict(linestyle='--', color='black', linewidth=1)

# ----------------------------------------------------- Script ---------------------------------------------------------

# Read in curtain polyline
polyline = list()
line_file = line_folder + '\\' + line_name
with open(line_file, 'r') as file:
    lines = file.readlines()
    for line in lines[1:]:
        polyline.append([float(aa) for aa in line.split(',')])
polyline = np.array(polyline)

# Prepare viewer object, figure & axes
viewer = Viewer(size=(300, 150), units='mm')
axes = viewer.figure.subplots(1, 3)
gs = axes[0].get_gridspec()
for ax in axes:
    viewer.figure.delaxes(ax)
ax_sheet = viewer.figure.add_subplot(gs[0])
ax_curtain = viewer.figure.add_subplot(gs[1:])
viewer.figure.subplots_adjust(bottom=0.20, top=0.95, wspace=0.15)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file)

# Plot the sheet patch collection
sheet = SheetPatch(ax_sheet, xtr, variable, sheet_datum, sheet_limits, edgecolor='face', **col_spec)

# Finish formatting sheet plot
for tick in ax_sheet.get_xticklabels():
        tick.set_rotation(20)

# Overlay polyline
ax_sheet.add_line(Line2D(polyline[:, 0], polyline[:, 1], **line_spec))

# Plot the curtain patch collection
curtain = CurtainPatch(ax_curtain, xtr, variable, polyline, edgecolor='face', **col_spec)

# Finish formatting curtain plot
ax_curtain.set_xlim(curtain_x_limit)
ax_curtain.set_ylim(curtain_y_limit)

# Add colour bar
col_bar = ColourBar(curtain.patch, location='right', offset=0.025, thickness=0.01, label=variable_name)

# Show plot
plt.show(block=True)
