# Import modules, functions & classes
from tfv.extractor import FvExtractor
from tfv.geometry import get_unit_vectors
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS FOLDER HERE'
res_name = r"Ash1990_C1_Shrt_3D_113_ks4p2_4p2.nc"

# Variable to plot
variable = 'hyp(V_x, V_y)'
variable_name = 'Velocity Magnitude [m/s]'

# Define vector variables
vector_variables = ['sum(vec((V_x, V_y))*ut, 1)', '4*W']

# Polyline
polyline = [[5.4987531400, 0.4102063287],
            [5.4987531400, 0.6102063287]]

# Colour settings
col_spec = dict(cmap=cm.jet, clim=[0, 0.5], norm=Normalize(0, 0.5))

# Axes settings
x_label = 'Chainage [m]'
y_label = 'Elevation [m]'
y_lim = (0.035, 0.065)

# Vector settings
vec_spec = dict(units='dots', scale_units='dots', scale=1/200, width=0.5,
                headwidth=10, headlength=10, angles='uv', pivot='middle')

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare viewer object, figure & axes
viewer = Viewer(size=(250, 150), units='mm')
ax = viewer.figure.subplots(1, 1)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Prepare extractor object
res_file = res_folder + '\\' + res_name
xtr = FvExtractor(res_file, is_spherical=False)

# Get unit tangent and unit normal vectors for curtain
polyline = np.array(polyline)
x, y, _ = xtr.get_intersection_data(polyline)
line_index, cell_index = xtr.get_curtain_cell_index(polyline)

ut, un = get_unit_vectors(x, y)
ut, un = tuple(v[line_index] for v in (ut, un))

# Plot the curtain patch collection
curtain = CurtainPatch(ax, xtr, variable, polyline, edgecolor='face', **col_spec)

curtain_vec = CurtainVector(ax, xtr, vector_variables, polyline, **vec_spec)

# Finish formatting plot
ax.set_ylim(y_lim[0], y_lim[1])
for tick in ax.get_xticklabels():
    tick.set_rotation(0)
ax.set_xlabel(x_label)
ax.set_ylabel(x_label)

# Add colour bar
col_bar = ColourBar(curtain.patch, offset=0.10)
col_bar.ax.set_xlabel(variable_name)

# Show plot
plt.show(block=True)