# Import modules, functions & classes
from tfv.timeseries import FvTimeSeries
from tfv.extractor import FvExtractor
from tfv.visual import *

# -------------------------------------------------- User  Input -------------------------------------------------------

# Result file folder and name
res_folder = r'ADD THE PATH TO YOUR RESULTS FOLDER HERE'
res_name = 'HYD_002.nc'
ts_name = 'HYD_002_time_series.nc'

# Variable to plot
variable = 'SAL'
location = 'Point_4'

# Axes settings
y_label = 'Water Surface Elevation [mAHD]'
x_label = 'Date [dd/mm/yyyy]'
date_fmt = '%d/%m/%Y'

x_limit = [dt.datetime(2011, 5, 1), dt.datetime(2011, 5, 7)]
y_limit = [-6, 0.5]
c_limit = [0, 38]

# ----------------------------------------------------- Script ---------------------------------------------------------

# Prepare extractor object
res_file = res_folder + '\\' + res_name
ts_file = res_folder + '\\' + ts_name
xtr = FvExtractor(res_file)
ts = FvTimeSeries(ts_file)

# Prepare viewer object, figure & axes
viewer = Viewer(size=(220, 220), units='mm')
axes = viewer.figure.subplots(3, 3)
gs = axes[0, 0].get_gridspec()
for ax in axes.flatten():
    viewer.figure.delaxes(ax)
ax_ts = viewer.figure.add_subplot(gs[0, :-1])
ax_hm = viewer.figure.add_subplot(gs[1:, :-1])
ax_pr = viewer.figure.add_subplot(gs[1:, -1])
viewer.figure.subplots_adjust(bottom=0.25, top=0.95, wspace=0.35, hspace=0.35)

# Plot profile visual
time_series = SeriesGlider(ax_ts, ts, variable, location, 'sigma', (0, 1))
hov_mol = HovmollerGlider(ax_hm, ts, variable, location, edgecolor='face', clim=c_limit)
profile = ProfileCell(ax_pr, xtr, variable, ts.locations[location])

# Set axes limits
ax_ts.set_xlim(x_limit)
ax_hm.set_xlim(x_limit)
ax_pr.set_xlim(c_limit)

# Set axes limits
ax_ts.set_ylim(c_limit)
ax_hm.set_ylim(y_limit)
ax_pr.set_ylim(y_limit)

# Format axes
fmt = DateFormatter(date_fmt)

ax_ts.xaxis.set_major_formatter(fmt)
for tick in ax_ts.get_xticklabels():
        tick.set_rotation(20)

ax_hm.xaxis.set_major_formatter(fmt)
for tick in ax_hm.get_xticklabels():
        tick.set_rotation(20)

viewer.figure.autofmt_xdate()

col_bar = ColourBar(hov_mol.patch, location='bottom', label='Salinity [PSU]', offset=-0.10)
bbox = list(col_bar.ax.get_position().bounds); bbox[2] = 3/4
col_bar.ax.set_position(bbox)

# Add labels
ax_ts.set_ylabel('Depth Averaged Salinity [PSU]')
ax_hm.set_ylabel('Elevation [m MSL]')
ax_pr.set_ylabel('Elevation [m MSL]')
ax_pr.set_xlabel('Salinity [PSU]')

# Show the figure
plt.show(block=True)