from tfv.particles import FvParticles
from tfv.extractor import FvExtractor
from tfv.visual import *

# Result file folder and name
res_folder = r'..\..\..\TUFLOWFV\results'
res_name = 'PTM_002_ptm.nc'
res_e_name = 'PTM_002.nc'

variable = 'hyp(V_x, V_y)'
variable_name = 'Velocity Magnitude [m/s]'

# Prepare extractor object
res_file = res_folder + '\\' + res_name
res_e_file = res_folder + '\\' + res_e_name
xtr = FvParticles(res_file)
xtr_e = FvExtractor(res_e_file)

# Prepare viewer object, figure & axes
viewer = Viewer(size=(200, 200), units='mm')
axes = viewer.figure.subplots(1, 1)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Plot mesh
xy = np.dstack((xtr_e.node_x[xtr_e.cell_node], xtr_e.node_y[xtr_e.cell_node]))
patch = PolyCollection(xy,  edgecolor='black', facecolor='None')
axes.add_collection(patch)

# Plot the particles in bottom 1m as black circles
ParticlesScatter(axes, xtr, datum='height', limits=[0, 1], shape='o', scale=0.00025, color='black', label='Bed (0m - 1m)')

# Plot the particles in top 1m as pink triangles
ParticlesScatter(axes, xtr, datum='depth', limits=[0, 1], shape='tri', scale=0.00025, color='pink', label='Water column (0m - 1m)')

axes.legend()

# Finish formatting plot
axes.set_aspect('equal')
for tick in axes.get_xticklabels():
        tick.set_rotation(20)
axes.set_xlim([159.07, 159.14])
axes.set_ylim([-31.45, -31.35])

plt.show(block=True)













