from tfv.particles import FvParticles
from tfv.extractor import FvExtractor
from tfv.visual import *

# Result file folder and name
res_folder = r'..\..\..\TUFLOWFV\results'
res_name = 'PTM_005_ptm.nc'
res_e_name = 'PTM_005.nc'
sheet_variable = 'H'
variable_name = 'Water Level [mAHD]'
vector_variables = ['V_x', 'V_y']

# Depth averaging setup
datum = 'sigma'
limits = [0, 1]

# Vector settings
vec_spec = dict(units='dots', scale_units='dots', scale=1/200, width=0.5,
                headwidth=10, headlength=10, angles='uv', pivot='middle')

# Colour settings
col_spec = dict(cmap=cm.jet, clim=[0.0, 0.5], norm=Normalize(0.0, 0.5))

# Prepare extractor object
res_file = res_folder + '\\' + res_name
res_e_file = res_folder + '\\' + res_e_name
xtr = FvParticles(res_file)
xtr_e = FvExtractor(res_e_file)

# Prepare viewer object, figure & axes
viewer = Viewer(size=(200, 200), units='mm')
axes = viewer.figure.subplots(1, 1)
viewer.figure.subplots_adjust(bottom=0.15, top=0.95)

# Plot mesh
xy = np.dstack((xtr_e.node_x[xtr_e.cell_node], xtr_e.node_y[xtr_e.cell_node]))
patch = PolyCollection(xy,  edgecolor='grey', facecolor='None')
axes.add_collection(patch)

# Plot the sheet patch collection
sheet = SheetPatch(axes, xtr_e, sheet_variable, datum, limits, shading='flat', edgecolor='face', **col_spec)
vector = SheetVector(axes, xtr_e, vector_variables, datum, limits, zorder=1, **vec_spec)

# Plot the particles in group 1 as black circles
ParticlesScatter(axes, xtr, shape='o', scale=0.0001, color='green', show='groupID==1', label='Clay')

# Plot the particles in group 1 as black circles
ParticlesScatter(axes, xtr, shape='o', scale=0.0001, color='black', show='groupID==2', label='Silt')

# Plot the particles in group 1 as black circles
ParticlesScatter(axes, xtr, shape='o', scale=0.0001, color='yellow', show='groupID==3', label='Fine Sand')

# Plot the particles in group 1 as black circles
ParticlesScatter(axes, xtr, shape='o', scale=0.0001, color='brown', show='groupID==4', label='Coarse Sand')

axes.legend()

# Finish formatting plot
axes.set_aspect('equal')
for tick in axes.get_xticklabels():
        tick.set_rotation(20)
axes.set_xlim([159.07, 159.14])
axes.set_ylim([-31.45, -31.35])

# Add colour bar
col_bar = ColourBar(sheet.patch, offset=0.08)
col_bar.ax.set_xlabel(variable_name)

plt.show(block=True)













